@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-license = ''' MIT License
+license = """ MIT License
 
 Copyright (c) 2020-2021 hrp/hrpzcf <hrpzcf@foxmail.com>
 
@@ -20,29 +20,20 @@ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.'''
+SOFTWARE."""
 
 from .errors import *
 from .fastpip import PyEnv, all_py_paths, cur_py_path, index_urls
-
-NAME = 'fastpip'
-version = 0, 5, 0
-AUTHOR = 'hrpzcf'
-EMAIL = 'hrpzcf@foxmail.com'
-WEBSITE = 'https://gitee.com/hrpzcf/fastpip'
-VERSION = '.'.join(map(str, version))
+from .versions import *
 
 __all__ = [
-    'PyEnv',
-    'all_py_paths',
-    'cur_py_path',
-    'index_urls',
-    'version',
-    '参数值异常',
-    '数据类型异常',
-    '文件查找异常',
-    '目录查找异常',
-    '适用平台异常',
-    'PyEnvNotFound',
-    'PathParamError',
+    "all_py_paths",
+    "cur_py_path",
+    "index_urls",
+    "ParamTypeError",
+    "ParamValueError",
+    "PathParamError",
+    "PyEnv",
+    "UnsupportedPlatform",
+    "version",
 ]
